# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.26
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.cert_signing_req import CertSigningReq  # noqa: E501
from agilicus_api.rest import ApiException

class TestCertSigningReq(unittest.TestCase):
    """CertSigningReq unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CertSigningReq
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.cert_signing_req.CertSigningReq()  # noqa: E501
        if include_optional :
            return CertSigningReq(
                metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                spec = agilicus_api.models.cert_signing_req_spec.CertSigningReqSpec(
                    org_id = '123', 
                    auto_renew = True, 
                    rotate_keys = True, 
                    request = '0', ), 
                status = agilicus_api.models.cert_signing_req_status.CertSigningReqStatus(
                    certificate_status = agilicus_api.models.cert_signing_req_certificate_status.CertSigningReqCertificateStatus(
                        certificates = [
                            agilicus_api.models.x509_certificate.X509Certificate(
                                certificate = '0', 
                                not_before = '2025-07-07T15:49:51.230+02:00', 
                                not_after = '2025-07-07T15:49:51.230+02:00', 
                                renewal_time = '2025-07-07T15:49:51.230+02:00', )
                            ], 
                        ready = True, 
                        message = '0', 
                        reason = 'pending', ), 
                    common_name = '0', 
                    dns_names = [
                        'a'
                        ], )
            )
        else :
            return CertSigningReq(
                spec = agilicus_api.models.cert_signing_req_spec.CertSigningReqSpec(
                    org_id = '123', 
                    auto_renew = True, 
                    rotate_keys = True, 
                    request = '0', ),
        )

    def testCertSigningReq(self):
        """Test CertSigningReq"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
